@@ -1,6 +1,6 @@
 use crate::api::AcknowledgeRequest;
 use crate::client::Client;
-use anyhow::Result;
+use crate::Error;
 use std::collections::HashMap;
 
 #[derive(Clone)]
@@ -15,7 +15,7 @@ pub struct Message {
 }
 
 impl Message {
-    pub async fn ack(&mut self) -> Result<()> {
+    pub async fn ack(&mut self) -> Result<(), Error> {
         let req = AcknowledgeRequest {
             subscription: self.subscription_name.clone(),
             ack_ids: vec![self.ack_id.clone()],
